﻿/**
 * ImageViewerDeluxe adds repositioning and resizing to ImageViewer. 
 * Updates at: http://www.moock.org/eas2/examples/.
 *
 * @author: Colin Moock
 * @version: 2.0.0
 */
class ImageViewerDeluxe extends ImageViewer {

  // Flag indicating whether the viewer should be 
  // scaled to match the size of the image.
  private var showFullImage:Boolean = false;

  public function ImageViewerDeluxe (target:MovieClip, 
                                depth:Number, 
                                x:Number, 
                                y:Number, 
                                w:Number, 
                                h:Number,
                                borderThickness:Number,
                                borderColor:Number) { 

    super(target, depth, x, y, w, h, borderThickness, borderColor);
  }

  /**
   * Sets the position of the viewer.
   *
   * @param   x        The new horizonatal position of the viewer.
   * @param   y        The new vertical position of the viewer.
   */
  public function setPosition (x:Number, y:Number):Void {
    container_mc._x = x;
    container_mc._y = y;
  }

  /**
   * Sets the size of the viewer (i.e., adjusts the 
   * border and mask size).
   *
   * @param   w        The new width of the viewer, in pixels.
   * @param   h        The new height of the viewer, in pixels.
   */
  public function setSize (w:Number, h:Number):Void {
    createImageClipMask(w, h);
    createBorder(w, h);
    container_mc.image_mc.setMask(container_mc.mask_mc);
  }

  /**
   * Returns the width of the clip that contains the image.
   */
  public function getImageWidth ():Number {
    return container_mc.image_mc._width;
  }

  /**
   * Returns the height of the clip that contains the image.
   */
  public function getImageHeight ():Number {
    return container_mc.image_mc._height;
  }

  /**
   * Set flag indicating whether the entire image should be
   * displayed or the image should be cropped to fit the viewer.
   *
   * @param   show   A flag indicating whether the viewer should be 
   *                 scaled to match the size of the image.
   */
  public function setShowFullImage(show:Boolean):Void {
    showFullImage = show;
  }

  /**
   * Returns flag indicating whether the entire image should be
   * displayed or the image should be cropped to fit the viewer.
   */
  public function getShowFullImage():Boolean {
    return showFullImage;
  }

  /**
   * Adjusts the size of the viewer so that the entire 
   * image is visible.
   */
  public function scaleViewerToImage ():Void {
    setSize(getImageWidth(), getImageHeight());
  }

  /**
   * MovieClipLoader handler. Triggered by imageLoader when loading is done.
   * Overrides ImageViewer.onLoadInit(), adding autosizing feature.
   */
  public function onLoadInit (target:MovieClip):Void {
    super.onLoadInit(target);

    if (showFullImage) {
      scaleViewerToImage();
    }
  }

}