﻿import util.*;
import mvcclock.*;
import mvc.*;

/**
 * An analog clock view for the ClockModel. This View has no user
 * inputs, so no Controller is required.
 */
class mvcclock.ClockAnalogView extends AbstractView {
  // Contains an instance of the ClockAnalogViewSymbol, which
  // depicts the clock on screen.
  private var clock_mc:MovieClip;

  /**
   * Constructor
   */
  public function ClockAnalogView (m:Observable, c:Controller,
                                   target:MovieClip, depth:Number,
                                   x:Number, y:Number) {
    // Invoke superconstructor, which sets up MVC relationships.
    // This view has no user inputs, so no controller is required.
    super(m, c);

    // Create UI.
    makeClock(target, depth, x, y);
  }

  /**
   * Creates the movie clip instance that will display the
   * time in analog format.
   *
   * @param   target   The clip in which to create the movie clip.
   * @param   depth   The depth at which to create the movie clip.
   * @param   x   The movie clip's horizontal position in target.
   * @param   y   The movie clip's vertical position in target.
   */
  public function makeClock (target:MovieClip, depth:Number, x:Number, y:Number):Void {
    clock_mc = target.attachMovie("ClockAnalogViewSymbol", "analogClock_mc", depth);
    clock_mc._x = x;
    clock_mc._y = y;
  }

  /**
   * Updates the state of the on-screen analog clock.
   * Invoked automatically by ClockModel.
   *
   * @param   o   The ClockModel object that is broadcasting an update.
   * @param   infoObj   A ClockUpdate instance describing the changes that
   *                    have occurred in the ClockModel.
   */
  public function update (o:Observable, infoObj:Object):Void {
    // Cast the generic infoObj to the ClockUpdate datatype.
    var info:ClockUpdate = ClockUpdate(infoObj);

    // Display the new time.
    var dayPercent:Number = (info.hour > 12 ? info.hour - 12 : info.hour) / 12;
    var hourPercent:Number = info.minute/60;
    var minutePercent:Number = info.second/60;
    clock_mc.hourHand_mc._rotation = 360 * dayPercent + hourPercent * (360 / 12);
    clock_mc.minuteHand_mc._rotation = 360 * hourPercent;
    clock_mc.secondHand_mc._rotation = 360 * minutePercent;

    // Fade the display out if the clock isn't running.
    if (info.isRunning) {
      clock_mc._alpha = 100;
    } else {
      clock_mc._alpha = 50;
    }
  }
}