﻿import util.*;
import mvcclock.*;
import mvc.*;

/**
 * A digital clock View for the ClockModel. This View has no user
 * inputs, so no Controller is required.
 */
class mvcclock.ClockDigitalView extends AbstractView {
  // The hour format.  
  private var hourFormat:Number = 24;
  // The separator character in the clock display.
  private var separator:String = ":";
  // The text field in which to display the clock.
  private var clock_txt:TextField;   

  /**
   * Constructor
   */
  public function ClockDigitalView (m:Observable,  c:Controller, 
                                    hf:Number, sep:String, target:MovieClip,
                                    depth:Number, x:Number, y:Number) {
    // Invoke superconstructor, which sets up MVC relationships.
    super(m, c);

    // Make sure the hour format specified is legal. If it is, use it.
    if (hf == 12) {
      hourFormat = 12;
    }

    // If a separator was provided, use it.
    if (sep != undefined) {
      separator = sep;
    }

    // Create UI.
    makeClock(target, depth, x, y);
  }

  /**
   * Creates the onscreen text field that will display the
   * time in digital format.
   *
   * @param   target   The clip in which to create the text field.
   * @param   depth   The depth at which to create the text field.
   * @param   x   The text field's horizontal position in target.
   * @param   y   The text field's vertical position in target.
   */
  public function makeClock (target:MovieClip, depth:Number, x:Number, y:Number):Void {
    // Make the text field.
    target.createTextField("clock_txt", depth, x, y, 0, 0);
    // Store a reference to the text field.
    clock_txt = target.clock_txt;
    // Assign text field characteristics.
    clock_txt.autoSize = "left";
    clock_txt.border = true;    
    clock_txt.background = true;
  }

  /**
   * Updates the state of the on-screen digital clock.
   * Invoked automatically by ClockModel.
   *
   * @param   o   The ClockModel object that is broadcasting an update.
   * @param   infoObj   A ClockUpdate instance describing the changes that
   *                    have occurred in the ClockModel.
   */
  public function update (o:Observable, infoObj:Object):Void {
    // Cast the generic infoObj to the ClockUpdate datatype.
    var info:ClockUpdate = ClockUpdate(infoObj);

    // Create a string representing the time in the appropriate format.
    var timeString:String = (hourFormat == 12)
           ? 
           formatTime12(info.hour, info.minute, info.second)
           :
           formatTime24(info.hour, info.minute, info.second);

    // Display the new time in the clock text field.
    clock_txt.text = timeString;

    // Fade the color of the display if the clock isn't running.
    if (info.isRunning) {
      clock_txt.textColor = 0x000000;
    } else {
      clock_txt.textColor = 0x666666;
    }
  }

  /**
   * Returns a formatted 24-hour time string.
   *
   * @param   h   The hour.
   * @param   m   The minute.
   * @param   s   The second.
   */
  private function formatTime24 (h:Number, m:Number, s:Number):String {
    var timeString:String = "";

    // Format hours...
    if (h < 10) {
      timeString += "0";
    }
    timeString += h + separator;

    // Format minutes...
    if (m < 10) {
      timeString += "0";
    }
    timeString += m + separator;

    // Format seconds...
    if (s < 10) {
      timeString += "0";
    }
    timeString += String(s);

    return timeString;
  }

  /**
   * Returns a formatted 12-hour time string.
   *
   * @param   h   The hour.
   * @param   m   The minute.
   * @param   s   The second.
   */
  private function formatTime12 (h:Number, m:Number, s:Number):String {
    var timeString:String = "";

    // Format hours...
    if (h == 0) {
      timeString += "12" + separator;
    } else if (h > 12) {
      timeString += (h - 12) + separator;
    } else {
      timeString += h + separator;
    }

    // Format minutes...
    if (m < 10) {
      timeString += "0";
    }
    timeString += m + separator;

    // Format seconds...
    if (s < 10) {
      timeString += "0";
    }
    timeString += String(s);

    return timeString;
  }
}