﻿import util.*;
import mvcclock.*;
import mvc.*;
import mx.controls.Button;

/**
 * Creates a user interface that can control a ClockModel.
 */
class mvcclock.ClockTools extends AbstractView {
  private var startBtn:Button;
  private var stopBtn:Button;
  private var resetBtn:Button;

  /**
   * Constructor
   */
  public function ClockTools (m:Observable, c:Controller, 
                              target:MovieClip, depth:Number,
                              x:Number, y:Number) {
    // Invoke superconstructor, which sets up MVC relationships.
    super(m, c);

    // Create UI.
    makeTools(target, depth, x, y);
  }

  /**
   * Returns the default controller for this view.
   */
  public function defaultController (model:Observable):Controller {
    return new ClockController(model);
  }

  /**
   * Creates a movie clip instance to hold the clock start, stop, 
   * and reset buttons, and also creates those buttons.
   *
   * @param   target   The clip in which to create the tools clip.
   * @param   depth   The depth at which to create the tools clip.
   * @param   x   The tools clip's horizontal position in target.
   * @param   y   The tools clip's vertical position in target.
   */
  public function makeTools (target:MovieClip, depth:Number,
                             x:Number, y:Number):Void {
    // Create a container movie clip.
    var tools_mc:MovieClip = target.createEmptyMovieClip("tools", depth);
    tools_mc._x = x;
    tools_mc._y = y;
 
    // Create UI buttons in the container clip.
    startBtn = tools_mc.createClassObject(Button, "start", 0);
    startBtn.label = "Start";
    startBtn.enabled = false;
    startBtn.addEventListener("click", getController());

    stopBtn = tools_mc.createClassObject(Button, "stop", 1);
    stopBtn.label = "Stop";
    stopBtn.enabled = false;
    stopBtn.move(startBtn.width + 5, startBtn.y);
    stopBtn.addEventListener("click", getController());

    resetBtn = tools_mc.createClassObject(Button, "reset", 2);
    resetBtn.label = "Reset";
    resetBtn.move(stopBtn.x + stopBtn.width + 5, startBtn.y);
    resetBtn.addEventListener("click", getController());
  }

  /**
   * Updates the state of the user interface.
   * Invoked automatically by ClockModel.
   *
   * @param   o   The ClockModel object that is broadcasting an update.
   * @param   infoObj   A ClockUpdate instance describing the changes that
   *                    have occurred in the ClockModel.
   */
  public function update (o:Observable, infoObj:Object):Void {
    // Cast the generic infoObj to the ClockUpdate datatype.
    var info:ClockUpdate = ClockUpdate(infoObj);

    // Enable the start button if the clock is stopped, or
    // the stop button if the clock is running.
    if (info.isRunning) {
      stopBtn.enabled = true;
      startBtn.enabled = false;
    } else {
      stopBtn.enabled = false;
      startBtn.enabled = true;
    }
  }
}